@@ -147,7 +147,7 @@ W niektórych krajach ich instalacja może być ograniczona prawnie.&lt;/p&gt;&l
     <message>
         <location filename="mainwindow.cpp" line="226"/>
         <source>Error running %1 command</source>
-        <translation type="unfinished"/>
+        <translation>Błąd podczas uruchamiania polecenia %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="238"/>
